searchNodes=[{"doc":"A utility for building GraphQL documents. (Strings that contain a GraphQL query/mutation.) Syntax GraphQLDocument.to_string converts nested lists/keyword lists into the analogous GraphQL syntax. Simply write lists and keyword lists &quot;as they look in GraphQL&quot;. Let's take a look at some examples. Object Fields To request a list of fields in an object, include them in a list: [ query : [ human : [ :name , :height ] ] ] GraphQLDocument.to_string/1 will take that Elixir structure and return &quot;&quot;&quot; query { human { name height } } &quot;&quot;&quot; Arguments When a field includes arguments, wrap the arguments and child fields in a tuple, like this: { args , fields } For example, GraphQLDocument.to_string/1 will take this Elixir structure [ query : [ human : { [ id : &quot;1000&quot; ] , [ :name , :height ] } ] ] and return this GraphQL document: &quot;&quot;&quot; query { human(id: &quot;1000&quot;) { name height } } &quot;&quot;&quot; Argument types and Enums GraphQLDocument.to_string/1 will translate Elixir primitives into the analogous GraphQL primitive type for arguments. GraphQL enums can be expressed as an atom (e.g. FOOT ) or in a tuple syntax, {:enum, &quot;FOOT&quot;} . For example: [ query : [ human : { [ id : &quot;1000&quot; ] , [ :name , height : { [ unit : FOOT ] , [ ] } ] } ] ] becomes query { human ( id : &quot;1000&quot; ) { name height ( unit : FOOT ) } } We can specify [unit: FOOT] as [unit: {:enum, &quot;FOOT&quot;}] , which is useful for interpolating dynamic values into the query. Expressing arguments without sub-fields Notice the slightly complicated syntax above: height: {[unit: FOOT], []} The way to include arguments is in an {args, fields} tuple. So if a field has arguments but no sub-fields, put [] where the sub-fields go. Nesting Fields Since GraphQL supports a theoretically infinite amount of nesting, you can also nest as much as needed in the Elixir structure. Furthermore, we can take advantage of Elixir's syntax feature that allows a regular list to be &quot;mixed&quot; with a keyword list: # Elixir allows lists with a Keyword List as the final members [ :name , :height , friends : [ :name , :age ] ] Using this syntax, we can build a nested structure like this: [ query : [ human : { [ id : &quot;1000&quot; ] , [ :name , :height , friends : { [ olderThan : 30 ] , [ :name , :height ] } ] } ] ] query { human ( id : &quot;1000&quot; ) { name height friends ( olderThan : 30 ) { name height } } } Aliases In order to name a field with an alias, follow the syntax below, where me is the alias and user is the field: [ query : [ me : { :user [ id : 100 ] , [ :name , :email ] } ] ] Which will emit this GraphQL document: query { me : user ( id : 100 ) { name email } }","ref":"GraphQLDocument.html","title":"GraphQLDocument","type":"module"},{"doc":"Wraps an enum string value (such as user input from a form) into a GraphQLDocument -friendly tuple. Example iex&gt; GraphQLDocument . enum ( &quot;soundex&quot; ) { :enum , &quot;soundex&quot; }","ref":"GraphQLDocument.html#enum/1","title":"GraphQLDocument.enum/1","type":"function"},{"doc":"Generates GraphQL syntax from a nested Elixir keyword list. Example iex&gt; GraphQLDocument . to_string ( query : [ user : { [ id : 3 ] , [ :name , :age , :height , documents : [ :filename , :url ] ] } ] ) &quot;&quot;&quot; query { user(id: 3) { name age height documents { filename url } } } \\ &quot;&quot;&quot;","ref":"GraphQLDocument.html#to_string/2","title":"GraphQLDocument.to_string/2","type":"function"},{"doc":"Build GraphQL document strings from Elixir primitives.","ref":"readme.html","title":"GraphQLDocument","type":"extras"},{"doc":"The goal of GraphQLDocument is to improve the developer experience of making GraphQL calls in Elixir by calling directly into GraphQL libraries such as Absinthe without making API calls. For Elixir projects that utilize LiveView and GraphQL, passing GraphQL queries as strings, GraphQLDocument can add value by making it easier to: Compose separate GraphQL documents together. Dynamically build GraphQL documents, e.g. including or excluding various parts. Interpolate arguments safely.","ref":"readme.html#better-dx-for-internal-graphql-queries","title":"GraphQLDocument - Better DX for internal GraphQL queries","type":"extras"},{"doc":"Add :graphql_document as a dependency in mix.exs : def deps do [ { :graphql_document , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"GraphQLDocument - Installation","type":"extras"},{"doc":"With Absinthe [ query : [ user : { [ id : 3 ] , [ :name , :age , :height , documents : [ :filename , :url ] ] } ] ] |&gt; GraphQLDocument . to_string ( ) |&gt; Absinthe . run ( MyProject.Schema ) For more information on syntax and features, read the docs in GraphQLDocument .","ref":"readme.html#usage","title":"GraphQLDocument - Usage","type":"extras"},{"doc":"Copyright 2022 United Community Bank Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"readme.html#license","title":"GraphQLDocument - License","type":"extras"}]